@@ -55,22 +55,22 @@ def feed_url(self):
         return False
 
 
-def send_package(self, title, link, language_id, season, episode, site):
+def send_package(self, title, link, language_id, season, episode, site, source, size,  imdb_id):
     englisch = ''
     if language_id == 2:
         englisch = '/Englisch'
     if self.filename == 'List_ContentShows_Shows':
-        link_placeholder = '[Episode' + englisch + '] - '
+        release_type = '[Episode' + englisch + '] - '
     elif self.filename == 'List_ContentShows_Shows_Regex':
-        link_placeholder = '[Episode/RegEx' + englisch + '] - '
+        release_type = '[Episode/RegEx' + englisch + '] - '
     elif self.filename == 'List_ContentShows_Seasons_Regex':
-        link_placeholder = '[Staffel/RegEx' + englisch + '] - '
+        release_type = '[Staffel/RegEx' + englisch + '] - '
     elif self.filename == 'List_ContentAll_Seasons':
-        link_placeholder = '[Staffel' + englisch + '] - '
+        release_type = '[Staffel' + englisch + '] - '
     elif self.filename == 'List_CustomDJ_Documentaries':
-        link_placeholder = '[Doku] - ' + englisch
+        release_type = '[Doku] - ' + englisch
     elif self.filename == 'List_CustomDJ_Documentaries_Regex':
-        link_placeholder = '[Doku/RegEx] - ' + englisch
+        release_type = '[Doku/RegEx] - ' + englisch
     else:
         return
     try:
@@ -87,9 +87,9 @@ def send_package(self, title, link, language_id, season, episode, site):
         download = add_decrypt(title, link, self.url)
         if download:
             self.db.store(title, 'added')
-            log_entry = link_placeholder + title + ' - [' + site + ']'
+            log_entry = release_type + title + ' - [' + site + '] - ' + size + ' - ' + source
             internal.logger.info(log_entry)
-            notify(["[CAPTCHA zu lösen] - " + log_entry])
+            notify([{"text": log_entry, "imdb_id": imdb_id}])
             return log_entry
 
 
@@ -221,15 +221,16 @@ def periodical_task(self):
                                 title = re.sub(r'\[.*\] ', '', post.title)
                                 package = self.parse_download_method(self, series_url, title, language_id)
                                 if package:
-                                    title = package[0]
+                                    title = package["title"]
                                     site = self._SITE
-                                    download_link = False
-                                    if not download_link:
-                                        download_link = package[1]
-                                    language_id = package[2]
-                                    season = package[3]
-                                    episode = package[4]
-                                    send_package(self, title, download_link, language_id, season, episode, site)
+                                    download_link = package["download_link"]
+                                    language_id = package["language_id"]
+                                    season = package["season"]
+                                    episode = package["episode"]
+                                    size = package["size"]
+                                    imdb_id = package["imdb_id"]
+                                    send_package(self, title, download_link, language_id, season, episode, site,
+                                                 post.source, size, imdb_id)
                         else:
                             internal.logger.debug(
                                 "%s - Englische Releases deaktiviert" % title)
@@ -264,15 +265,16 @@ def periodical_task(self):
                                 title = re.sub(r'\[.*\] ', '', post.title)
                                 package = self.parse_download_method(self, series_url, title, language_id)
                                 if package:
-                                    title = package[0]
+                                    title = package["title"]
                                     site = self._SITE
-                                    download_link = False
-                                    if not download_link:
-                                        download_link = package[1]
-                                    language_id = package[2]
-                                    season = package[3]
-                                    episode = package[4]
-                                    send_package(self, title, download_link, language_id, season, episode, site)
+                                    download_link = package["download_link"]
+                                    language_id = package["language_id"]
+                                    season = package["season"]
+                                    episode = package["episode"]
+                                    size = package["size"]
+                                    imdb_id = package["imdb_id"]
+                                    send_package(self, title, download_link, language_id, season, episode, site,
+                                                 post.source, size, imdb_id)
                         else:
                             internal.logger.debug(
                                 "%s - Englische Releases deaktiviert" % title)
@@ -314,15 +316,16 @@ def periodical_task(self):
                                         continue
                                     package = self.parse_download_method(self, series_url, title, language_id)
                                     if package:
-                                        title = package[0]
+                                        title = package["title"]
                                         site = self._SITE
-                                        download_link = False
-                                        if not download_link:
-                                            download_link = package[1]
-                                        language_id = package[2]
-                                        season = package[3]
-                                        episode = package[4]
-                                        send_package(self, title, download_link, language_id, season, episode, site)
+                                        download_link = package["download_link"]
+                                        language_id = package["language_id"]
+                                        season = package["season"]
+                                        episode = package["episode"]
+                                        size = package["size"]
+                                        imdb_id = package["imdb_id"]
+                                        send_package(self, title, download_link, language_id, season, episode, site,
+                                                     post.source, size, imdb_id)
                             else:
                                 internal.logger.debug(
                                     "%s - Englische Releases deaktiviert" % title)
@@ -362,15 +365,16 @@ def periodical_task(self):
                                         continue
                                     package = self.parse_download_method(self, series_url, title, language_id)
                                     if package:
-                                        title = package[0]
+                                        title = package["title"]
                                         site = self._SITE
-                                        download_link = False
-                                        if not download_link:
-                                            download_link = package[1]
-                                        language_id = package[2]
-                                        season = package[3]
-                                        episode = package[4]
-                                        send_package(self, title, download_link, language_id, season, episode, site)
+                                        download_link = package["download_link"]
+                                        language_id = package["language_id"]
+                                        season = package["season"]
+                                        episode = package["episode"]
+                                        size = package["size"]
+                                        imdb_id = package["imdb_id"]
+                                        send_package(self, title, download_link, language_id, season, episode, site,
+                                                     post.source, size, imdb_id)
                                 else:
                                     internal.logger.debug(
                                         "%s - Englische Releases deaktiviert" % title)
