@@ -10,7 +10,11 @@ import re
 from bs4 import BeautifulSoup
 
 from feedcrawler import internal
-from feedcrawler.common import decode_base64, sanitize, check_hoster, simplified_search_term_in_title, check_is_site
+from feedcrawler.common import check_hoster
+from feedcrawler.common import check_is_site
+from feedcrawler.common import decode_base64
+from feedcrawler.common import keep_alphanumeric_with_special_characters
+from feedcrawler.common import simplified_search_term_in_title
 from feedcrawler.config import CrawlerConfig
 from feedcrawler.db import ListDb, FeedDb
 from feedcrawler.myjd import add_decrypt
@@ -93,12 +97,11 @@ def download(payload):
 
     if site == "SF":
         password = sf
-        series_url = False
+        source = href
 
-        epoch = str(datetime.datetime.now().timestamp()).replace('.', '')[:-3]
-        season_page = get_url(href)
+        season_page = get_url(source)
         season_id = re.findall(r"initSeason\('(.+?)\',", season_page)[0]
-
+        epoch = str(datetime.datetime.now().timestamp()).replace('.', '')[:-3]
         api_url = 'https://' + sf + '/api/v1/' + season_id + '/season/ALL?lang=ALL&_=' + epoch
 
         response = get_url(api_url)
@@ -151,8 +154,9 @@ def download(payload):
     else:
         site = "SJ"
         password = sj
-        series_url = 'https://' + sj + href
-        series_info = get_url(series_url)
+        source = 'https://' + sj + href
+
+        series_info = get_url(source)
         series_id = re.findall(r'data-mediaid="(.*?)"', series_info)[0]
         api_url = 'https://' + sj + '/api/media/' + series_id + '/releases'
 
@@ -162,7 +166,7 @@ def download(payload):
     listen = ["List_ContentShows_Shows", "List_ContentAll_Seasons"]
     for liste in listen:
         cont = ListDb(liste).retrieve()
-        list_title = sanitize(title)
+        list_title = keep_alphanumeric_with_special_characters(title)
         if not cont:
             cont = ""
         if list_title not in cont:
@@ -321,22 +325,24 @@ def download(payload):
 
     notify_array = []
     for title in matches:
+        size = ""  # currently no way to get this from the API
+
         db = FeedDb('FeedCrawler')
-        if not series_url:
+        if site == "SF":
             try:
                 url = real_urls[title]
             except:
                 url = False
                 print("Keine passende URL für " + title + " gefunden. Vermutlich hat SF die Seitenstruktur geändert!")
         else:
-            url = series_url
+            url = source
 
         if url:
             if add_decrypt(title, url, password):
                 db.store(title, 'added')
-                log_entry = u'[Suche/Serie] - ' + title + ' - ' + site
+                log_entry = u'[Suche/Serie] - ' + title + ' - [' + site + '] - ' + size + ' - ' + source
                 internal.logger.info(log_entry)
-                notify_array.append(log_entry)
+                notify_array.append({"text": log_entry})
 
     notify(notify_array)
 
