@@ -78,7 +78,7 @@ def check_url(start_time):
 def check_if_blocked(site, url):
     try:
         # These can be checked the same way
-        if site in ["BY", "FX", "HW", "DD"]:
+        if site in ["BY", "FX", "HW", "DD", "NK"]:
             status = cached_request(url, dont_cache=True)["status_code"]
             if not status == 200 or status == 403:
                 return True
@@ -166,10 +166,11 @@ def get_urls_async(urls):
 
     with concurrent.futures.ThreadPoolExecutor(max_workers=5) as executor:
         future_to_url = {executor.submit(load_url, url): url for url in urls}
-        for future in concurrent.futures.as_completed(future_to_url):
-            future_to_url[future]
+        futures = concurrent.futures.as_completed(future_to_url)
+        for future in futures:
+            source = future_to_url[future]
             try:
-                results.append(future.result())
+                results.append([future.result(), source])
             except Exception:
                 pass
-    return [results]
+    return results
