@@ -23,7 +23,8 @@ import feedcrawler.search.shared.content_all
 import feedcrawler.search.shared.content_shows
 from feedcrawler import internal
 from feedcrawler import version
-from feedcrawler.common import Unbuffered
+from feedcrawler.common import Unbuffered, keep_alphanumeric_with_special_characters, \
+    keep_alphanumeric_with_regex_characters, keep_numbers
 from feedcrawler.common import decode_base64
 from feedcrawler.common import get_to_decrypt
 from feedcrawler.common import is_device
@@ -215,7 +216,7 @@ def app_container():
 
     @app.get(prefix + "/api/log/")
     @auth_basic(is_authenticated_user)
-    def get_delete_log():
+    def get_log():
         try:
             log = []
             if os.path.isfile(internal.log_file):
@@ -250,7 +251,7 @@ def app_container():
 
     @app.delete(prefix + "/api/log_entry/<b64_entry>")
     @auth_basic(is_authenticated_user)
-    def get_delete_log_entry(b64_entry):
+    def delete_log_entry(b64_entry):
         try:
             entry = decode_base64(b64_entry)
             log = []
@@ -283,6 +284,7 @@ def app_container():
             dd_conf = CrawlerConfig('CustomDD')
             f_conf = CrawlerConfig('CustomF')
             jf_conf = CrawlerConfig('CustomJF')
+            helper_conf = CrawlerConfig('SponsorsHelper')
             return {
                 "settings": {
                     "general": {
@@ -375,6 +377,9 @@ def app_container():
                     },
                     "jf": {
                         "wait_time": to_int(jf_conf.get("wait_time")),
+                    },
+                    "sponsors_helper": {
+                        "max_attempts": to_int(helper_conf.get("max_attempts")),
                     }
                 }
             }
@@ -534,6 +539,12 @@ def app_container():
                 wait_time = '6'
             section.save("wait_time", wait_time)
 
+            section = CrawlerConfig("SponsorsHelper")
+            max_attempts = to_str(data['sponsors_helper']['max_attempts'])
+            if to_int(max_attempts) > 10:
+                max_attempts = '10'
+            section.save("max_attempts", max_attempts)
+
             return "Success"
         except:
             return abort(400, "Failed")
@@ -617,7 +628,7 @@ def app_container():
 
             bl = ' / '.join(list(filter(None, [fx, ff, hw, ww, nk, by])))
             s = ' / '.join(list(filter(None, [sj, sf])))
-            f = ' / '.join(list(filter(None, [ff, sf])))
+            f = ' / '.join(list(filter(None, [sf, ff])))
             sjbl = ' / '.join(list(filter(None, [s, bl])))
             jf = ' / '.join(list(filter(None, [sj, dj, sf, ff])))
 
@@ -845,12 +856,15 @@ def app_container():
             try:
                 myjd = get_info()
                 packages_to_decrypt = get_to_decrypt()
+                general_conf = CrawlerConfig('FeedCrawler')
+                packages_per_myjd_page = to_int(general_conf.get("packages_per_myjd_page"))
             except (TokenExpiredException, RequestTimeoutException):
                 get_device()
                 if not internal.device or not is_device(internal.device):
                     return abort(500, "Failed")
                 myjd = get_info()
                 packages_to_decrypt = get_to_decrypt()
+                packages_per_myjd_page = 3
             if myjd:
                 return {
                     "downloader_state": myjd[1],
@@ -862,7 +876,8 @@ def app_container():
                         "linkgrabber_offline": myjd[4][2],
                         "linkgrabber_failed": myjd[4][3],
                         "to_decrypt": packages_to_decrypt
-                    }
+                    },
+                    "packages_per_myjd_page": packages_per_myjd_page
                 }
         except:
             pass
@@ -1146,30 +1161,34 @@ def app_container():
     def post_lists():
         try:
             data = request.json
-            ListDb("List_ContentAll_Movies").store_list(
-                data['mb']['filme'].split('\n'))
-            ListDb("List_ContentAll_Seasons").store_list(
-                data['mbsj']['staffeln'].split('\n'))
-            ListDb("List_ContentAll_Movies_Regex").store_list(
-                data['mb']['regex'].split('\n'))
-            ListDb("List_ContentShows_Shows").store_list(
-                data['sj']['serien'].split('\n'))
-            ListDb("List_ContentShows_Shows_Regex").store_list(
-                data['sj']['regex'].split('\n'))
-            ListDb("List_ContentShows_Seasons_Regex").store_list(
-                data['sj']['staffeln_regex'].split('\n'))
-            ListDb("List_CustomDJ_Documentaries").store_list(
-                data['dj']['dokus'].split('\n'))
-            ListDb("List_CustomDJ_Documentaries_Regex").store_list(
-                data['dj']['regex'].split('\n'))
 
-            try:
-                replace_dd = 'https://' + CrawlerConfig('Hostnames').get('dd') + '/rss/'
-            except:
-                replace_dd = 'https:///rss/'
-                pass
-            ListDb("List_CustomDD_Feeds").store_list(
-                data['dd']['feeds'].replace(replace_dd, "").split('\n'))
+            mb_filme = keep_alphanumeric_with_special_characters(data['mb']['filme']).split('\n')
+            ListDb("List_ContentAll_Movies").store_list(mb_filme)
+
+            mbsj_staffeln = keep_alphanumeric_with_special_characters(data['mbsj']['staffeln']).split('\n')
+            ListDb("List_ContentAll_Seasons").store_list(mbsj_staffeln)
+
+            mb_regex = keep_alphanumeric_with_regex_characters(data['mb']['regex']).split('\n')
+            ListDb("List_ContentAll_Movies_Regex").store_list(mb_regex)
+
+            sj_serien = keep_alphanumeric_with_special_characters(data['sj']['serien']).split('\n')
+            ListDb("List_ContentShows_Shows").store_list(sj_serien)
+
+            sj_regex = keep_alphanumeric_with_regex_characters(data['sj']['regex']).split('\n')
+            ListDb("List_ContentShows_Shows_Regex").store_list(sj_regex)
+
+            sj_staffeln_regex = keep_alphanumeric_with_regex_characters(data['sj']['staffeln_regex']).split('\n')
+            ListDb("List_ContentShows_Seasons_Regex").store_list(sj_staffeln_regex)
+
+            dj_dokus = keep_alphanumeric_with_special_characters(data['dj']['dokus']).split('\n')
+            ListDb("List_CustomDJ_Documentaries").store_list(dj_dokus)
+
+            dj_regex = keep_alphanumeric_with_regex_characters(data['dj']['regex']).split('\n')
+            ListDb("List_CustomDJ_Documentaries_Regex").store_list(dj_regex)
+
+            dd_feeds = keep_numbers(data['dd']['feeds']).split('\n')
+            ListDb("List_CustomDD_Feeds").store_list(dd_feeds)
+
             return "Success"
         except:
             return abort(400, "Failed")
@@ -1481,11 +1500,17 @@ if (cnlAllowed && document.getElementsByClassName("cnlform").length) {
                     "password"]
                 decrypt_password = decrypt["password"]
 
+            try:
+                max_attempts = CrawlerConfig('SponsorsHelper').get("max_attempts")
+            except:
+                max_attempts = 3
+
             return {
                 "to_decrypt": {
                     "name": decrypt_name,
                     "url": decrypt_url,
-                    "password": decrypt_password
+                    "password": decrypt_password,
+                    "max_attempts": max_attempts
                 }
             }
         except:
@@ -1497,8 +1522,8 @@ if (cnlAllowed && document.getElementsByClassName("cnlform").length) {
             if name:
                 if remove_decrypt(name):
                     try:
-                        notify([
-                            "[FeedCrawler Sponsors Helper nicht erfolgreich] - " + name + " (Paket nach 3 Versuchen gelöscht)"])
+                        notify([{
+                            "text": "[FeedCrawler Sponsors Helper nicht erfolgreich] - " + name + " (Paket nach 3 Versuchen gelöscht)"}])
                     except:
                         print(u"Benachrichtigung konnte nicht versendet werden!")
                     print(
@@ -1694,7 +1719,7 @@ if (cnlAllowed && document.getElementsByClassName("cnlform").length) {
                         if not db.retrieve(name):
                             db.store(name, 'added')
                         try:
-                            notify(["[FeedCrawler Sponsors Helper erfolgreich] - " + name])
+                            notify([{"text": "[FeedCrawler Sponsors Helper erfolgreich] - " + name}])
                         except:
                             print(u"Benachrichtigung konnte nicht versendet werden!")
                         print(u"[FeedCrawler Sponsors Helper erfolgreich] - " + name)
